LateResult<T> class sealed

Implementers

Constructors

LateResult.failure([Object? failure, StackTrace? stackTrace])
const
factory
LateResult.pending()
const
factory
LateResult.success(T value)
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromStream<T>(Stream<T> stream) → Stream<LateResult<T>>